@@ -55,7 +55,13 @@ program grafic1
 #endif
 
   !c
-  !c  Top grid mesh size.
+  !c  Top grid size. This means the number of particles that
+  !c  are to be placed at approximately regular intervals in the
+  !c  1st, 2nd or 3rd orthogonal direction in the simulation box.
+  !c  The total number of particles will be np1*np2*np3. Mpgrafic
+  !c  normally outputs only the peculiar velocities of these particles;
+  !c  the time evolution program should set particle positions
+  !c  consistent with the Zel'dovich approximation.
   !c
   ! Can be overridden at ./configure stage, e.g.:
   ! CFLAGS="${CFLAGS} -DMPGRAFIC_NP_DEFAULT=1024" ./configure
@@ -150,10 +156,10 @@ program grafic1
         write(*,'(a)')'Most recent source code:'
         write(*,'(a)')'git clone https://broukema@bitbucket.org/broukema/mpgrafic.git'
         write(*,'(a)')''
-        write(*,'(a)')' -?, --help                 Give this help list'
-        write(*,'(a)')'     --np=INTEGER           Number of particles per dimension'
-        write(*,'(a)')'     --usage                Give a short usage message'
-        write(*,'(a)')' -V, --version              Print program version'
+        write(*,'(a)')' -?, --help        Give this help list'
+        write(*,'(a)')'     --np=INTEGER  Number of particles per dimension (grid size will be INTEGER^3)'
+        write(*,'(a)')'     --usage       Give a short usage message'
+        write(*,'(a)')' -V, --version     Print program version'
      elseif(command_line_arg1 == '--usage')then
         help_only_arg = .true.
         write(*,'(a)')'Usage: mpgrafic [-?hV] [--np=INTEGER] [--help] [--usage]'
